package com.wasu.cs.mvp.IView;

import com.wasu.cs.model.ChildrenData;
import com.wasu.cs.model.DemandProgram;

/**
 * Created by jeepc on 2016/11/2.
 */
public interface IChildrenSongView {
    void showLoading();
    void hideLoading();
    void onDataLoaded(ChildrenData childrenData);
    void showErrorExitDlg();
    void playVideo(DemandProgram demandProgram, int position);
    boolean uiIsFinishing();
    void onPriceChange(int pos,int fee);
    void playNextVideo();
}
